import os

from OpenFont import FontSpecificNameID, NameID, NameTable_Format_0, OpenFont, PredefinedNameID, TrueTypeOutlines, parse_file

def search_names(font: OpenFont, nameID: NameID) -> str:
	assert isinstance(font.naming_table, NameTable_Format_0)

	for nameRecord in font.naming_table.nameRecord:
		if nameRecord.nameID == nameID:
			return nameRecord.string
	
	assert False, f"Name not found: {nameID}"

def print_font(font: OpenFont):
	assert isinstance(font.naming_table, NameTable_Format_0)
	assert isinstance(font.outlines, TrueTypeOutlines)

	name = search_names(font, PredefinedNameID.FULL_NAME)

	print(name, f"({font.maximum_profile.numGlyphs} glyphs, {font.naming_table.count} names)")
	if font.font_variations:
		axis_names = [search_names(font, FontSpecificNameID(axis.axisNameID)) for axis in font.font_variations.font_variations.axes]
		num_instances = font.font_variations.font_variations.instanceCount
		print(f"\tAxes: [{', '.join(axis_names)}] ({num_instances} instances)")

path = "examples/"
# path = "examples/android_fonts/api_level/30"
# path = "examples/android_fonts/api_level/30/NotoNaskhArabic-Bold.ttf"
path = "examples/JetBrainsMono-2.304/"
if os.path.isfile(path):
	try:
		font = parse_file(path)
	except AssertionError as err:
		print("Failed:", path)
		raise err
	print_font(font)
else:
	for root, dirs, files in os.walk(path):
		for file in files:
			_, ext = os.path.splitext(file)
			match ext:
				case '.ttf':
					file_path = os.path.join(root, file)
					try:
						font = parse_file(file_path)
					except AssertionError as err:
						print("Failed:", file_path)
						raise err
					print_font(font)
